@@ -7,13 +7,16 @@
 ##' @param y y position
 ##' @param n number of circle
 ##' @param labeller function to label radius
+##' @param label_position a character string indicating the position of labels,
+##'   "right" (default) or "left" or any abbreviation of these
+##' @param ... other text arguments passed on to \code{\link[ggplot2:layer]{ggplot2::layer()}}
 ##' @importFrom ggplot2 aes_
 ##' @importFrom ggplot2 geom_segment
 ##' @importFrom ggplot2 geom_text
 ##' @export
 ##' @return layer
 ##' @author Guangchuang Yu
-geom_scatterpie_legend <- function(radius, x, y, n=5, labeller) {
+geom_scatterpie_legend <- function(radius, x, y, n=5, labeller, label_position = "right", ...) {
     ## rvar <- as.character(mapping)["r"]
     ## if (is_fixed_radius(rvar)) {
     ##     radius <- as.numeric(rvar)
@@ -47,9 +50,18 @@ geom_scatterpie_legend <- function(radius, x, y, n=5, labeller) {
         dd$label <- dd$r
     }
 
+    label_position <- match.arg(label_position, c("right", "left"))
+    if (label_position == "right") {
+      hjust <- "left"
+      sign <- `+`
+    } else {
+      hjust <- "right"
+      sign <- `-`
+    }
+
     list(
         geom_arc_bar(aes_(x0=~x, y0=~y, r0=~r, r=~r, start=~start, end=~end), data=dd, inherit.aes=FALSE),
-        geom_segment(aes_(x=~x, xend=~x+maxr*1.5, y=~y+r, yend=~y+r), data=dd, inherit.aes=FALSE),
-        geom_text(aes_(x=~x+maxr*1.6, y=~y+r, label=~label), data=dd, hjust='left', inherit.aes=FALSE)
+        geom_segment(aes_(x=~x, xend=~sign(x, maxr*1.5), y=~y+r, yend=~y+r), data=dd, inherit.aes=FALSE),
+        geom_text(aes_(x=~sign(x, maxr*1.6), y=~y+r, label=~label), data=dd, hjust=hjust, inherit.aes=FALSE, ... = ...)
     )
 }
